@@ -26,6 +26,6 @@ route_verb!(patch => "PATCH");
 route_verb!(options => "OPTIONS");
 
 #[proc_macro]
-pub fn router(input: TokenStream) -> TokenStream {
+pub fn routes(input: TokenStream) -> TokenStream {
     router::routes_macro(input)
 }
